@@ -3,7 +3,7 @@
 // RcppCommon.h: Rcpp R/C++ interface class library -- common include and defines statements
 //
 // Copyright (C) 2008 - 2009 Dirk Eddelbuettel
-// Copyright (C) 2009 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2009 - 2012 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -41,14 +41,8 @@
 # error "This compiler is not supported"
 #endif
 
-/* we define this so that INT64_MAX, etc ... are defined */
-#define __STDC_LIMIT_MACROS
-#include <limits.h>
-
-
 #include <Rcpp/config.h>
 #include <Rcpp/macros/unroll.h>
-#include <stdint.h>
 
 void logTxtFunction(const char* file, const int line, const char* expression ) ;
 
@@ -124,6 +118,7 @@ namespace Rcpp{
 #include <numeric>
 #include <algorithm>
 #include <complex>
+#include <limits.h>
 #include <typeinfo>
 #include <Rcpp/sprintf.h>
 
@@ -256,15 +251,15 @@ SEXP stack_trace( const char *file, int line) ;
     #include <typeinfo>
 #endif
 
-// #ifdef __GNUC__
-// #ifdef __GXX_EXPERIMENTAL_CXX0X__
-// #ifdef LONG_LONG_MAX
-//     __extension__ typedef long long int rcpp_long_long_type;
-//     __extension__ typedef unsigned long long int rcpp_ulong_long_type;
-//     #define RCPP_HAS_LONG_LONG_TYPES
-// #endif
-// #endif
-// #endif
+#ifdef __GNUC__
+#ifdef __GXX_EXPERIMENTAL_CXX0X__
+#ifdef LONG_LONG_MAX
+    __extension__ typedef long long int rcpp_long_long_type;
+    __extension__ typedef unsigned long long int rcpp_ulong_long_type;
+    #define RCPP_HAS_LONG_LONG_TYPES
+#endif
+#endif
+#endif
 
 // DO NOT CHANGE THE ORDER OF THESE INCLUDES
 #include <Rcpp/traits/integral_constant.h>
@@ -288,7 +283,6 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/get_na.h>
 #include <Rcpp/traits/is_trivial.h>
 #include <Rcpp/traits/init_type.h>
-#include <Rcpp/traits/or.h>
 
 #include <Rcpp/traits/is_const.h>
 #include <Rcpp/traits/is_reference.h>
@@ -303,7 +297,6 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/internal/r_vector.h>
 #include <Rcpp/r_cast.h>
 
-#include <Rcpp/int64/int64_lite.h>
 #include <Rcpp/internal/wrap_forward.h>
 
 #include <Rcpp/Date_forward.h>
@@ -333,4 +326,8 @@ RcppExport SEXP RcppXPtrExample_get_external_pointer(SEXP );
 #include <Rcpp/routines.h>
 #include <Rcpp/cache.h>
 
+// "Rcout" iostream class contributed by Jelmer Ypma
+#include <Rcpp/iostream/Rstreambuf.h>
+#include <Rcpp/iostream/Rostream.h>
+
 #endif
